#######################################################################
# This script is used to produce all figures of Luyssaert et al       #
# expet the figure 1 wich was made in inkscape                        #
# Author: Guillaume Marie                                             #
#######################################################################

source('Libview.R')
library(gstat)
library(raster)
library(sp)
library(maptools)
library(ggmap)
library(ctmm)
library(stringr)

#######################################################################
#out <- '/home/guilaume/Outputs/ORCHIDEE/'

#### European mask #####################
mask=nc_open('European_mask.nc')
mask.x=ncvar_get(mask,'countries')
lat=mask$dim$lat$vals; lon=mask$dim$lon$vals
mask.x=melt(mask.x,varnames=c("X","Y"), value.name='mask')
mask.x[,'Lon']=rep(lon,length(lat))
mask.x[,'Lat']=sort(rep(lat,length(lon)),decreasing=TRUE)

##### Pixel resolutions ##################################
trash=list()
trash[['CWAC']] <- read.table(paste0('ResolXY_YE/SBG_CWAC_YE.test'),header=TRUE)
landsum.RES <- melt(trash,c('X','Y','RESOLUTION_X', 'RESOLUTION_Y','an'))
landsum.RES <- landsum.RES[,-c(5,6)]
Tot.Arera.Europe <- sum(landsum.RES[,'RESOLUTION_X']/1000*landsum.RES[,'RESOLUTION_Y']/1000,na.rm=TRUE)

##### reshape SBG dataset : VEGET_MAX at PFT level ##################################
simu2='Bestt2m'
trash=list()
for(i in simu2) trash[[i]] <- read.table(paste0(out,'Vegetmax_SBG_PFT_OL/landPFT_SBG_',i,'.test'),header=TRUE)
landsum.SBG <- melt(trash,c('X','Y','PFT','FOREST_MANAGED','VEGET_MAX','an'))
names(landsum.SBG)[dim(landsum.SBG)[2]]='Simu'
landsum.SBG <- merge(landsum.SBG,landsum.RES,c('X','Y'),all=TRUE)
landsum.SBG <- na.omit(landsum.SBG)
landsum.SBG <- dcast(landsum.SBG, X+Y+Simu+PFT+Lat+Lon+RESOLUTION_X+RESOLUTION_Y+Region ~ an, value.var='VEGET_MAX')
landsum.SBG[,'2012_km'] <- landsum.SBG[,'2012']*(landsum.SBG[,'RESOLUTION_X']/1000)*(landsum.SBG[,'RESOLUTION_Y']/1000)
landsum.SBG[,'2100_km'] <- landsum.SBG[,'2100']*(landsum.SBG[,'RESOLUTION_X']/1000)*(landsum.SBG[,'RESOLUTION_Y']/1000)
landsum.SBG[,'DelArea'] <- landsum.SBG[,'2100_km'] - landsum.SBG[,'2012_km']
landsum.SBG[,'CD'] <- CD.names3[landsum.SBG[,'PFT']+3]
landsum.SBG <- summarySE(landsum.SBG, 'DelArea', groupvars=c('Simu','CD','X','Y'), na.rm=TRUE)
landsum.SBG[,'DelAreaC'] <- cut(landsum.SBG[,'sum'],labels=c(seq(-1950,1950,100)),breaks=c(seq(-2000,2000,100)))
landsum.SBG <- landsum.SBG[,c('X','Y','CD','DelAreaC')]
landsum.SBG <- merge(landsum.RES,landsum.SBG,c('X','Y'))

###################################################################################
#                                                                                 #
# This part is used to extract information from the decomposition files           #
#                                                                                 #
###################################################################################
vardecomp=c('dta_mod','dta_eps','dta_atm','dta_g','dta_h','dta_le','dta_Rsi','dta_alpha','dta_calc','dta_direct','dta_indirect')
Decompfinal <- data.frame(Y=sort(rep(1:119,128)),X=rep(1:128,119))
load(paste0(out,"decomp2_BESTT2M_BWAC_FM.image"))

for(j in vardecomp){   
    DecompLonLat <- as.data.frame(decomp[[j]])
    DecompLonLat <- melt(DecompLonLat)
    DecompLonLat[,'Y'] <- sort(rep(1:119,128))
    DecompLonLat[,'X'] <- rep(1:128,119)
    DecompLonLat <- DecompLonLat[,c('X','Y','value')]
    names(DecompLonLat) <- c('X','Y',j)
    Decompfinal[,j] <- DecompLonLat[,j]
}
Decompfinal[,'sumheat'] <-Decompfinal[,'dta_h']+ Decompfinal[,'dta_le'] 
Decompfinal[,'Circulation'] <- Decompfinal[,'dta_mod']-Decompfinal[,'dta_calc']
Decompfinal2 <- merge(Decompfinal,landsum.SBG,c('X','Y'))

write.table(Decompfinal2,'dataset_for_figure2.txt')

DecompLatsum=NULL
for(h in c('BESTT2M')){
    #for(m in c('ANN')){
    for(m in c('DJ','FM','AM','JJ','AS','ON')){       
        load(paste0(out,"decomp2_",h,"_BWAC_",m,".image"))    
        DecompLat <- NULL
        l=0
        for(i in 1:119){
            l=l+1
            k=0; res=numeric(7) 
            for(j in vardecomp[1:9]){
                k=k+1
                res[k] <- mean(decomp[[j]][,i],na.rm=TRUE)
            }
        DecompLat <- rbind(DecompLat,c(l,res))
        }
        DecompLat <- as.data.frame(DecompLat)  
        names(DecompLat) <- c('Y',vardecomp[1:9])
        DecompLat[,'circ'] <- DecompLat[,'dta_mod']-DecompLat[,'dta_calc']
        DecompLat[,'heat'] <-  DecompLat[,'dta_h']+ DecompLat[,'dta_le']
        
        DecompLat <- melt(DecompLat[c('Y','dta_mod','dta_eps','dta_g','heat','dta_Rsi','dta_alpha','circ')],c('Y','dta_mod'))
        DecompLat <- merge(DecompLat,unique(mask.x[,c('Y','Lat')]),'Y')
        DecompLat[,'month'] <- m
        assign(paste0("DecompLat",m),DecompLat)
        DecompLatsum <- rbind(DecompLatsum,DecompLat)
    }
}

write.table(DecompLatsum,'dataset_for_extended_figure1.txt')

landsum.tot <- summarySE(Decompfinal2, 'dta_mod', groupvars=c('CD','DelAreaC','Lat'), na.rm=TRUE)
write.table(landsum.tot,'dataset_for_extended_figure2.txt')

##### Optimized management maps (theorical) ##################################
optim <- fread('Optim2100_W-B.txt')
optim <- merge(optim,mask.x,c('X','Y'),all=TRUE)
optim <- subset(optim,mask==1)

write.table(optim,'dataset_for_extended_figure3.txt')

############################################# Graphics #########################################################

pdf('figure2.pdf',width=10,height=5)
x1 <- ggplot(aes(x = Lon, y = Lat, fill=dta_mod), data = Decompfinal2)+ geom_tile() +
    coord_cartesian(xlim=c(-10, 40),  ylim=c(37,70)) + ggtitle('')+
    scale_fill_gradientn(bquote(Delta~T[a]~(K)),colors = c('navy',"blue","cyan","white", "yellow","red",'darkred'),limits=c(-0.7,0.7)) +
    theme(legend.position=c(0.9,0.8),axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0, 0, 0, 0, "cm"))+
    borders("world", xlim=c(-10,25), ylim=c(40,70), colour='grey10')+ ylab('') + xlab('Longitude')+ annotate('text',x=-10,y=70,label='(a)')
x2 <- ggplot(aes_string(x = "Lat", y = 'value', fill='variable'), data = DecompLatFM) +
    geom_col(position = "stack")+ xlim(37,70)+ ggtitle('')+
     geom_line(aes(x=Lat, y=dta_mod),size=0.25)+ ylim(-2,2)+ xlab('')+ geom_hline(yintercept = 0,linetype=2)+
    coord_flip() + ylab(bquote(Delta~T[a]~(K)))+ theme(legend.position=c(0.15,0.25),axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0, 0, 0, 0, "cm"))+
    scale_fill_brewer(name = '', palette = "Set2", labels = c(bquote(Delta~T[a] / epsilon),bquote(Delta~T[a] / G),bquote(Delta~T[a] / LE+H),bquote(Delta~T[a] / R[si]),bquote(Delta~T[a] / alpha),bquote(Delta~T[a] / circ)))+ annotate('text',x=70,y=-2,label='(b)')
    print(grid.arrange(x1,x2,ncol=2, nrow=1, widths=c(2, 2)))
dev.off()

pdf("extended_figure1.pdf",width=10,height=4, onefile=TRUE)
    for(i in  c('AM','JJ','AS','ON')){
        x <- ggplot(aes_string(x = "Lat", y = 'value', fill='variable'), data = get(paste0('DecompLat',i))) +
        geom_col(position = "stack")+ xlim(37,70)+ ggtitle(i)+ guides(fill = 'none')+
        geom_line(aes(x=Lat, y=dta_mod),size=0.25)+ ylim(-2,2)+ xlab('')+ geom_hline(yintercept = 0,linetype=2)+
        coord_flip() + ylab(bquote(Delta~T[a]~(K)))+ theme(axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0.1, 0, 0, 0, "cm"))+
        scale_fill_brewer(name = '', palette = "Set2", labels = c(bquote(Delta~T[a] / epsilon),bquote(Delta~T[a] / G),bquote(Delta~T[a] / LE+H),bquote(Delta~T[a] / R[si]),bquote(Delta~T[a] / alpha),bquote(Delta~T[a] / circ)))
        assign(paste0('x',i),x)
    }
     xDJ <- ggplot(aes_string(x = "Lat", y = 'value', fill='variable'), data = get('DecompLatDJ')) +
         geom_col(position = "stack")+ xlim(37,70)+ ggtitle('DJ')+ guides(fill = 'none')+
         geom_line(aes(x=Lat, y=dta_mod),size=0.25)+ ylim(-2,2)+ geom_hline(yintercept = 0,linetype=2)+
         coord_flip() + ylab(bquote(Delta~T[a]~(K)))+ theme(plot.margin = margin(0.1, 0, 0, 0.5, "cm"))+xlab('Latitude')+
         scale_fill_brewer(name = '', palette = "Set2", labels = c(bquote(Delta~T[a] / epsilon),bquote(Delta~T[a] / G),bquote(Delta~T[a] / LE+H),bquote(Delta~T[a] / R[si]),bquote(Delta~T[a] / alpha),bquote(Delta~T[a] / circ)))
     xFM <- ggplot(aes_string(x = "Lat", y = 'value', fill='variable'), data = get('DecompLatFM')) +
         geom_col(position = "stack")+ xlim(37,70)+ ggtitle('FM')+
         geom_line(aes(x=Lat, y=dta_mod),size=0.25)+ ylim(-2,2)+ xlab('')+ geom_hline(yintercept = 0,linetype=2)+
         coord_flip() + ylab(bquote(Delta~T[a]~(K)))+ theme(legend.position=c(-0.05,0.25),axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0.1, 0, 0, 0, "cm"))+
         scale_fill_brewer(name = '', palette = "Set2", labels = c(bquote(Delta~T[a] / epsilon),bquote(Delta~T[a] / G),bquote(Delta~T[a] / LE+H),bquote(Delta~T[a] / R[si]),bquote(Delta~T[a] / alpha),bquote(Delta~T[a] / circ)))
print(grid.arrange(xDJ,xFM,xAM,xJJ,xAS,xON,ncol=6, nrow=1))
dev.off()


pdf('extended_figure2.pdf',width=7,height=10)
ggplot() + geom_tile(data=subset(landsum.tot, CD=='D'),aes(x=as.numeric(as.character(DelAreaC)),y=Lat,fill=dta_mod), colour='black')+
    geom_vline(xintercept=0,linetype=2)+ ylim(37,70)+ theme(plot.margin = margin(0, 0, 0, 0.5, "cm"))+
    scale_fill_gradientn(bquote(Delta~T[a]~(K)),colors = c('navy',"blue","cyan","white", "yellow","red",'darkred'),limits=c(-0.6,0.6)) + ggtitle('') + 
    ylab('Latitude') + xlab(bquote(Delta~ 'decidious area ('*km^2*')'))
dev.off()

pdf('extended_figure4.pdf',width=10,height=5)
m1 <- ggplot(aes(x = Lon, y = Lat, fill= as.factor(BestAlbW)), data = optim)+ geom_tile() +
    coord_cartesian(xlim=c(-10, 40),  ylim=c(37,70)) + ggtitle('')+   
    theme(legend.position=c(0.9,0.8),axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0, 0, 0, 0, "cm"))+
    borders("world", xlim=c(-10,25), ylim=c(40,70), colour='grey10')+ ylab('') + xlab('Longitude')+ annotate('text',x=-10,y=70,label='(a)')
m2 <- ggplot(aes(x = Lon, y = Lat, fill= as.factor(BestAlbB)), data = optim)+ geom_tile() +
    coord_cartesian(xlim=c(-10, 40),  ylim=c(37,70)) + ggtitle('')+   
    theme(legend.position=c(0.9,0.8),axis.text.y= element_blank(),axis.ticks.y= element_blank(), plot.margin = margin(0, 0, 0, 0, "cm"))+
    borders("world", xlim=c(-10,25), ylim=c(40,70), colour='grey10')+ ylab('') + xlab('Longitude')+ annotate('text',x=-10,y=70,label='(b)')
    grid.arrange(m1,m2,nrow=1,ncol=2)
dev.off()

################################ END GRAPHICS ###########################################################
