#!/usr/bin/env Rscript
# This script is used to create a Forest management map and a Replanting strategy map of Europe in which each pixel give the optimal scenario

#This library containt all the foction created
source('libR_optim.R')

############################################ SETUP ###################################
# These names correspond to 5 senarios available to optimize offline simulation
simu1=c('CWA12017','CWA22017','CWC22017','CWD22017','CWD32017') # W for RCP 8.5
simu3=c('CBA12017','CBA22017','CBC22017','CBD22017','CBD32017') # B for RCP 4.5
# This names correspond to 5 senarios available to optimize online simulation
simu2=c('BWA1','BWA2','BWC2','BWD2','BWD3') # 20 years (2100-2120) online simulation
###################### SETUP END #####################################################


########################## MAIN CODE #######################################################
# ref = reference simulation (BWAC, CWAC2017, CBAC2017)                                    #
# sim = a group of simulation which represent the strategy (CWA1,CWD2,....etc)             #
# an = you can average the target variable over year (begin year , end year)               #
# var = the target variable(alb_vis, atmco2, t2m)                                          #
# ths = thresold below which the best strategy is always BAU                               #
# method = min or max target variable                                                      #
# sour = type of output file (SRF, ATM, SBG)                                               #
# hash = how the output files are cut (YE, MO, DA)                                         #
# XXXXXX <- Optimize.MA(ref,sim,an,var,ths,method,sour,hash)                               #
############################################################################################
# Best and worst optimum for near surface temperature (t2m)
land.mint2m <- Optimize.MA('BWAC',simu2,c(2101,2103),'t2m',0.005,'which.min','ATM','MO')
land.maxt2m <- Optimize.MA('BWAC',simu2,c(2101,2103),'t2m',0.005,'which.max','ATM','MO')
# Best and worst optimum for Albedo (alb_vis)
land.minAlb <- Optimize.MA('CBAC2017',simu1,c(2075,2100),'alb_vis',0.001,'which.min','SRF','YE')
land.maxAlbB <- Optimize.MA('CBAC2017',simu3,c(2075,2100),'alb_vis',0.001,'which.max','SRF','YE')
land.minAlbB <- Optimize.MA('CBAC2017',simu3,c(2075,2100),'alb_vis',0.001,'which.min','SRF','YE')
land.minAlbW <- Optimize.MA('CWAC2017',simu1,c(2075,2100),'alb_vis',0.001,'which.min','SRF','YE')
land.maxAlbW <- Optimize.MA('CWAC2017',simu1,c(2075,2100),'alb_vis',0.001,'which.max','SRF','YE')
# Best and worst optimum for CO2 sequestration (atmco2)
land.minLCAW <- Optimize.MA('CWAC2017',simu1,c(2075,2100),'atmco2',0.001,'which.min','LCA','YE')
land.maxLCAW <- Optimize.MA('CWAC2017',simu1,c(2075,2100),'atmco2',0.001,'which.max','LCA','YE')
land.minLCAB <- Optimize.MA('CBAC2017',simu1,c(2075,2100),'atmco2',0.001,'which.min','LCA','YE')
land.maxLCAB <- Optimize.MA('CBAC2017',simu1,c(2075,2100),'atmco2',0.001,'which.max','LCA','YE')

OP.Maps1=data.frame(X=land.minAlbW[,'X'],Y=land.minAlbW[,'Y'],BestAlbW=land.maxAlbW[,'best1'],WorstAlbW=land.minAlbW[,'best1'],BestAlbB=land.maxAlbB[,'best1'],WorstAlbB=land.minAlbB[,'best1'])
write.table(OP.Maps,'Optim2100_W-B.txt', row.name=FALSE)

OP.Maps2=data.frame(X=land.mint2m[,'X'],Y=land.mint2m[,'Y'],BestLCA=land.minLCA[,'best'],WorstLCA=land.maxLCA[,'best'],BestAlbedo=land.maxAlb[,'best'],WorstAlbedo=land.minAlb[,'best'],Bestt2m=land.mint2m[,'best'],Worstt2m=land.maxt2m[,'best'])
write.table(OP.Maps,'Optim2100Wnew_RCP8.5.txt', row.name=FALSE)

############################################################################################
# Op = optimum strategy dataset                                                            #
# OpMap = file name of the reference FM maps                                               #
# target = name of the senario (BestAlbedo,BestLCA...)                                     #
#                                                                                          #
# XXXXXX <- remap(Op,OpMap,target)                                                      #
# XXXXXX <- remap.SP(Op,OpMap,target)                                                      #
############################################################################################

# ReConstruct the Optimal Forest management strategy NETCDF maps according to LCA, Albedo, or t2m
print('Remapping Forest strategy for BestAlbedo simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/BestAlbedoLimRCP8.5_fm_strat_map_2100_mean.nc','BestAlbedo')
print('Remapping Forest strategy for WorstAlbedo simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/WorstAlbedoLimRCP8.5_fm_strat_map_2100_mean.nc','WorstAlbedo')
print('Remapping Forest strategy for BestLCA simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/BestLCALimRCP8.5_fm_strat_map_2100_mean.nc','BestLCA')
print('Remapping Forest strategy for WorstLCA simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/WorstLCALimRCP8.5_fm_strat_map_2100_mean.nc','WorstLCA')
print('Remapping Forest strategy for Bestt2m simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/Bestt2mLimRCP8.5_fm_strat_map_2100_mean.nc','Bestt2m')
print('Remapping Forest strategy for Worstt2m simulation...')
remap(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/RGRID/Worstt2mLimRCP8.5_fm_strat_map_2100_mean.nc','Worstt2m')

# REConstruct the Optimal replant strategy NETCDF maps according to LCA, Albedo, or t2m
print('Remapping Replanting strategy for BestAlbedo simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/BestAlbedo_replant.nc','BestAlbedo')
print('Remapping Replanting strategy for BestLCA simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/BestLCA_replant.nc','BestLCA')
print('Remapping Replanting strategy for WorstAlbedo simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/WorstAlbedo_replant.nc','WorstAlbedo')
print('Remapping Replanting strategy for WorstLCA simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/WorstLCA_replant.nc','WorstLCA')
print('Remapping Replanting strategy for WorstLCA simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/Bestt2m_replant.nc','Bestt2m')
print('Remapping Replanting strategy for WorstLCA simulation...')
remap.SP(OP.Maps2,'/ccc/work/cont003/dofoco/dofoco/MAPS/FM/FUTURE/RGRID/Worstt2m_replant.nc','Worstt2m')

################################# MAIN CODE END ######################################################
